==> mypy_boto3_mgh-0.2.2-py3-none-any.whl: mypy_boto3_mgh/helpers.py <==
"Helper functions for mgh service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_mgh.client import Client
from mypy_boto3_mgh.paginator import (
    ListCreatedArtifactsPaginator,
    ListDiscoveredResourcesPaginator,
    ListMigrationTasksPaginator,
    ListProgressUpdateStreamsPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('mgh')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("mgh", **kwargs)
    return boto3.client("mgh", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_created_artifacts_paginator(
    client: Client,
) -> ListCreatedArtifactsPaginator:
    """
    Equivalent of `client.get_paginator('list_created_artifacts')`, returns a correct type.
    """
    return client.get_paginator("list_created_artifacts")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_discovered_resources_paginator(
    client: Client,
) -> ListDiscoveredResourcesPaginator:
    """
    Equivalent of `client.get_paginator('list_discovered_resources')`, returns a correct type.
    """
    return client.get_paginator("list_discovered_resources")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_migration_tasks_paginator(client: Client) -> ListMigrationTasksPaginator:
    """
    Equivalent of `client.get_paginator('list_migration_tasks')`, returns a correct type.
    """
    return client.get_paginator("list_migration_tasks")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_progress_update_streams_paginator(
    client: Client,
) -> ListProgressUpdateStreamsPaginator:
    """
    Equivalent of `client.get_paginator('list_progress_update_streams')`, returns a correct type.
    """
    return client.get_paginator("list_progress_update_streams")

==> mypy_boto3_mgh-0.2.8-py3-none-any.whl: mypy_boto3_mgh/helpers.py <==
"Helper functions for mgh service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_mgh.client import Client
from mypy_boto3_mgh.paginator import (
    ListCreatedArtifactsPaginator,
    ListDiscoveredResourcesPaginator,
    ListMigrationTasksPaginator,
    ListProgressUpdateStreamsPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('mgh')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("mgh", **kwargs)
    return boto3.client("mgh", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_created_artifacts_paginator(client: Client) -> ListCreatedArtifactsPaginator:
    """
    Equivalent of `client.get_paginator('list_created_artifacts')`, returns a correct type.
    """
    return client.get_paginator("list_created_artifacts")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_discovered_resources_paginator(client: Client) -> ListDiscoveredResourcesPaginator:
    """
    Equivalent of `client.get_paginator('list_discovered_resources')`, returns a correct type.
    """
    return client.get_paginator("list_discovered_resources")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_migration_tasks_paginator(client: Client) -> ListMigrationTasksPaginator:
    """
    Equivalent of `client.get_paginator('list_migration_tasks')`, returns a correct type.
    """
    return client.get_paginator("list_migration_tasks")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_progress_update_streams_paginator(
    client: Client,
) -> ListProgressUpdateStreamsPaginator:
    """
    Equivalent of `client.get_paginator('list_progress_update_streams')`, returns a correct type.
    """
    return client.get_paginator("list_progress_update_streams")
